==> monaco-vscode-api-11.1.2.tgz: package/vscode/src/vs/editor/browser/widget/diffEditor/diffEditor.contribution.js <==
import { Codicon } from '../../../../base/common/codicons.js';
import { ToggleCollapseUnchangedRegions, ToggleShowMovedCodeBlocks, ToggleUseInlineViewWhenSpaceIsLimited, RevertHunkOrSelection, SwitchSide, ExitCompareMove, CollapseAllUnchangedRegions, ShowAllUnchangedRegions, AccessibleDiffViewerNext, AccessibleDiffViewerPrev } from './commands.js';
import { EditorContextKeys } from '../../../common/editorContextKeys.js';
import { localize } from '../../../../nls.js';
import { registerAction2, MenuRegistry, MenuId } from '../../../../platform/actions/common/actions.js';
import { CommandsRegistry } from '../../../../platform/commands/common/commands.js';
import { ContextKeyExpr, ContextKeyEqualsExpr } from '../../../../platform/contextkey/common/contextkey.js';
import './registrations.contribution.js';

registerAction2(ToggleCollapseUnchangedRegions);
registerAction2(ToggleShowMovedCodeBlocks);
registerAction2(ToggleUseInlineViewWhenSpaceIsLimited);
MenuRegistry.appendMenuItem(MenuId.EditorTitle, {
    command: {
        id: ( (new ToggleUseInlineViewWhenSpaceIsLimited())).desc.id,
        title: ( localize(1674, "Use Inline View When Space Is Limited")),
        toggled: ( (ContextKeyExpr.has('config.diffEditor.useInlineViewWhenSpaceIsLimited'))),
        precondition: ( (ContextKeyExpr.has('isInDiffEditor'))),
    },
    order: 11,
    group: '1_diff',
    when: ( (ContextKeyExpr.and(
        EditorContextKeys.diffEditorRenderSideBySideInlineBreakpointReached,
         (ContextKeyExpr.has('isInDiffEditor'))
    ))),
});
MenuRegistry.appendMenuItem(MenuId.EditorTitle, {
    command: {
        id: ( (new ToggleShowMovedCodeBlocks())).desc.id,
        title: ( localize(1675, "Show Moved Code Blocks")),
        icon: Codicon.move,
        toggled: ContextKeyEqualsExpr.create('config.diffEditor.experimental.showMoves', true),
        precondition: ( (ContextKeyExpr.has('isInDiffEditor'))),
    },
    order: 10,
    group: '1_diff',
    when: ( (ContextKeyExpr.has('isInDiffEditor'))),
});
registerAction2(RevertHunkOrSelection);
for (const ctx of [
    { icon: Codicon.arrowRight, key: ( (EditorContextKeys.diffEditorInlineMode.toNegated())) },
    { icon: Codicon.discard, key: EditorContextKeys.diffEditorInlineMode }
]) {
    MenuRegistry.appendMenuItem(MenuId.DiffEditorHunkToolbar, {
        command: {
            id: ( (new RevertHunkOrSelection())).desc.id,
            title: ( localize(1676, "Revert Block")),
            icon: ctx.icon,
        },
        when: ( (ContextKeyExpr.and(EditorContextKeys.diffEditorModifiedWritable, ctx.key))),
        order: 5,
        group: 'primary',
    });
    MenuRegistry.appendMenuItem(MenuId.DiffEditorSelectionToolbar, {
        command: {
            id: ( (new RevertHunkOrSelection())).desc.id,
            title: ( localize(1677, "Revert Selection")),
            icon: ctx.icon,
        },
        when: ( (ContextKeyExpr.and(EditorContextKeys.diffEditorModifiedWritable, ctx.key))),
        order: 5,
        group: 'primary',
    });
}
registerAction2(SwitchSide);
registerAction2(ExitCompareMove);
registerAction2(CollapseAllUnchangedRegions);
registerAction2(ShowAllUnchangedRegions);
MenuRegistry.appendMenuItem(MenuId.EditorTitle, {
    command: {
        id: AccessibleDiffViewerNext.id,
        title: ( localize(1678, "Open Accessible Diff Viewer")),
        precondition: ( (ContextKeyExpr.has('isInDiffEditor'))),
    },
    order: 10,
    group: '2_diff',
    when: ( (ContextKeyExpr.and(
         (EditorContextKeys.accessibleDiffViewerVisible.negate()),
         (ContextKeyExpr.has('isInDiffEditor'))
    ))),
});
CommandsRegistry.registerCommandAlias('editor.action.diffReview.next', AccessibleDiffViewerNext.id);
registerAction2(AccessibleDiffViewerNext);
CommandsRegistry.registerCommandAlias('editor.action.diffReview.prev', AccessibleDiffViewerPrev.id);
registerAction2(AccessibleDiffViewerPrev);

==> monaco-vscode-api-16.0.6.tgz: package/vscode/src/vs/editor/browser/widget/diffEditor/diffEditor.contribution.js <==

import { Codicon } from '../../../../base/common/codicons.js';
import { ToggleCollapseUnchangedRegions, ToggleShowMovedCodeBlocks, ToggleUseInlineViewWhenSpaceIsLimited, RevertHunkOrSelection, SwitchSide, ExitCompareMove, CollapseAllUnchangedRegions, ShowAllUnchangedRegions, AccessibleDiffViewerNext, AccessibleDiffViewerPrev } from './commands.js';
import { EditorContextKeys } from '../../../common/editorContextKeys.js';
import { localize } from '../../../../nls.js';
import { registerAction2, MenuRegistry, MenuId } from '../../../../platform/actions/common/actions.js';
import { CommandsRegistry } from '../../../../platform/commands/common/commands.js';
import { ContextKeyExpr, ContextKeyEqualsExpr } from '../../../../platform/contextkey/common/contextkey.js';
import './registrations.contribution.js';

registerAction2(ToggleCollapseUnchangedRegions);
registerAction2(ToggleShowMovedCodeBlocks);
registerAction2(ToggleUseInlineViewWhenSpaceIsLimited);
MenuRegistry.appendMenuItem(MenuId.EditorTitle, {
    command: {
        id: ( new ToggleUseInlineViewWhenSpaceIsLimited()).desc.id,
        title: ( localize(183, "Use Inline View When Space Is Limited")),
        toggled: ( ContextKeyExpr.has('config.diffEditor.useInlineViewWhenSpaceIsLimited')),
        precondition: ( ContextKeyExpr.has('isInDiffEditor')),
    },
    order: 11,
    group: '1_diff',
    when: ( ContextKeyExpr.and(
        EditorContextKeys.diffEditorRenderSideBySideInlineBreakpointReached,
        ( ContextKeyExpr.has('isInDiffEditor'))
    )),
});
MenuRegistry.appendMenuItem(MenuId.EditorTitle, {
    command: {
        id: ( new ToggleShowMovedCodeBlocks()).desc.id,
        title: ( localize(184, "Show Moved Code Blocks")),
        icon: Codicon.move,
        toggled: ContextKeyEqualsExpr.create('config.diffEditor.experimental.showMoves', true),
        precondition: ( ContextKeyExpr.has('isInDiffEditor')),
    },
    order: 10,
    group: '1_diff',
    when: ( ContextKeyExpr.has('isInDiffEditor')),
});
registerAction2(RevertHunkOrSelection);
for (const ctx of [
    { icon: Codicon.arrowRight, key: ( EditorContextKeys.diffEditorInlineMode.toNegated()) },
    { icon: Codicon.discard, key: EditorContextKeys.diffEditorInlineMode }
]) {
    MenuRegistry.appendMenuItem(MenuId.DiffEditorHunkToolbar, {
        command: {
            id: ( new RevertHunkOrSelection()).desc.id,
            title: ( localize(185, "Revert Block")),
            icon: ctx.icon,
        },
        when: ( ContextKeyExpr.and(EditorContextKeys.diffEditorModifiedWritable, ctx.key)),
        order: 5,
        group: 'primary',
    });
    MenuRegistry.appendMenuItem(MenuId.DiffEditorSelectionToolbar, {
        command: {
            id: ( new RevertHunkOrSelection()).desc.id,
            title: ( localize(186, "Revert Selection")),
            icon: ctx.icon,
        },
        when: ( ContextKeyExpr.and(EditorContextKeys.diffEditorModifiedWritable, ctx.key)),
        order: 5,
        group: 'primary',
    });
}
registerAction2(SwitchSide);
registerAction2(ExitCompareMove);
registerAction2(CollapseAllUnchangedRegions);
registerAction2(ShowAllUnchangedRegions);
MenuRegistry.appendMenuItem(MenuId.EditorTitle, {
    command: {
        id: AccessibleDiffViewerNext.id,
        title: ( localize(187, "Open Accessible Diff Viewer")),
        precondition: ( ContextKeyExpr.has('isInDiffEditor')),
    },
    order: 10,
    group: '2_diff',
    when: ( ContextKeyExpr.and(( EditorContextKeys.accessibleDiffViewerVisible.negate()), ( ContextKeyExpr.has('isInDiffEditor')))),
});
CommandsRegistry.registerCommandAlias('editor.action.diffReview.next', AccessibleDiffViewerNext.id);
registerAction2(AccessibleDiffViewerNext);
CommandsRegistry.registerCommandAlias('editor.action.diffReview.prev', AccessibleDiffViewerPrev.id);
registerAction2(AccessibleDiffViewerPrev);
